==> ubee512-1.3.0.tar.gz: ubee512-1.3.0/src/ubee512.h <==
/* ubee512 Header */

#ifndef HEADER_UBEE512_H
#define HEADER_UBEE512_H

#include "SDL.h"

void z80_exec_ratio (int divider);

//==============================================================================
// Compile time options,  these are normally only changed for testing purposes.
//==============================================================================
// define this for the default XTAL frequency (in MHz)
#define	XTALFREQ 3.375

// defines the target frame rate (frames per second) wanted.
#define FRAMERATE 30

// define this for the default tape out sample frequency (in Hz)
#define	TAPE_SAMPLE_FREQ 22050

// define this for the default tape volume level.
#define	TAPE_VOLUME 16

// define the default serial port values.
#define	SERIAL_RX_BAUD 300
#define	SERIAL_TX_BAUD 300
#define	SERIAL_DATABITS 8
#define	SERIAL_STOPBITS 1

// Sound hold-off delays and speed adjustments.
// It has been found that the Z80 speed increase is no longer required.  If
// sound does break up then try putting the SPEED_PCT_ADJ values back to
// that shown in the commented out line or a lesser amount could also be
// tried.
//
// The sound hold-off values have also been reduced from 100 to 75 mS.
#ifdef MINGW
#define SOUND_HOLD_OFF 75
#define SPEED_PCT_ADJ 0.0	// x% faster to stop audio break up
//#define SPEED_PCT_ADJ 6.0	// x% faster to stop audio break up
#else
#define SOUND_HOLD_OFF 75
#define SPEED_PCT_ADJ 0.0	// x% faster to stop audio break up
//#define SPEED_PCT_ADJ 9.0	// x% faster to stop audio break up
#endif 

// define where the logged data will go
#define LOGFILE	"ubee512_log.txt"

// define this to emulate an alpha+ (Premium) graphics model.
#define	use_alpha_p

// define this for a 512KB DRAM model.  If not defined then 128KB DRAM model.
#define use_dram512

// define this to debug DRAM banked memory (fills banks with numbers on init)
// The Microbee built in monitor can be used to check banks i.e:
// Select bank with ROMs disabled:
// >O 50 4, <-- (5,6,7, 44, 45, 46, 47, 84, 85, 86, 87, C4, C5, C6, C7)
// Examine memory:
// >E 8000 will show both lower and upper DRAM banks
//#define use_dramdebug

// define this to have Premium cursor keys on UP, DOWN, LEFT and RIGHT keys.
// if not defined then these are on the function keys.
#define use_cursorkeys

// define the following debug options to report on ports on stdout
#define use_resetinfo
//#define use_pioinfo
//#define use_debug_memmap_mode
//#define use_debug_vdu_colcont_r
//#define use_debug_vdu_colcont_w
//#define use_debug_vdu_lvdat_r
//#define use_debug_vdu_lvdat_w
//#define use_debug_vdu_latchrom

//#define use_debug_disk_read_abort

//#define use_debug_getkeystate_shift
//#define use_debug_getkeystate_lower

// define the following options to be reported to stdout
#define use_info_disk_open
//#define use_info_disk_read

#endif /* HEADER_UBEE512_H */

==> ubee512-1.4.0.tar.gz: ubee512-1.4.0/src/ubee512.h <==
/* ubee512 Header */

#ifndef HEADER_UBEE512_H
#define HEADER_UBEE512_H

#include "SDL.h"

// model definitions
enum
   {
    MOD_P512K,
    MOD_512K,
    MOD_P256K,
    MOD_256K,
    MOD_P128K,
    MOD_128K,
    MOD_256TC,
    MOD_P64K,
    MOD_64K,
    MOD_APC,
    MOD_PPC85,    
    MOD_PC85,
    MOD_PC,
    MOD_IC,
    MOD_2MHZ
   };

void event_handler (void);
void z80_exec_ratio (int divider);
void console_output (void);

//==============================================================================
// Compile time options,  these are normally only changed for testing purposes.
//==============================================================================
// define this for the default XTAL frequency (in MHz)
#define	XTALFREQ 3.375

// defines the target frame rate (frames per second) wanted.
#define FRAMERATE 30

// define this for the default tape out sample frequency (in Hz)
#define	TAPE_SAMPLE_FREQ 22050

// define this for the default tape volume level.
#define	TAPE_VOLUME 16

// define the default serial port values.
#define	SERIAL_RX_BAUD 300
#define	SERIAL_TX_BAUD 300
#define	SERIAL_DATABITS 8
#define	SERIAL_STOPBITS 1

// Sound hold-off delays and speed adjustments.
// It has been found that the Z80 speed increase is no longer required.  If
// sound does break up then try putting the SPEED_PCT_ADJ values back to
// that shown in the commented out line or a lesser amount could also be
// tried.
//
// The sound hold-off values have also been reduced from 100 to 75 mS.
#ifdef MINGW
#define SOUND_HOLD_OFF 75
#define SPEED_PCT_ADJ 0.0	// x% faster to stop audio break up
//#define SPEED_PCT_ADJ 6.0	// x% faster to stop audio break up
#else
#define SOUND_HOLD_OFF 75
#define SPEED_PCT_ADJ 0.0	// x% faster to stop audio break up
//#define SPEED_PCT_ADJ 9.0	// x% faster to stop audio break up
#endif 

// define where the logged data will go
#define LOGFILE	"ubee512_log.txt"

// define this to emulate an alpha+ (Premium) graphics model.  This is
// still used to determine the Z80 ports used between standard and Premium
// models.
#define	use_alpha_p

// define this to debug DRAM banked memory (fills banks with numbers on init)
// The Microbee built in monitor can be used to check banks i.e:
// Select bank with ROMs disabled:
// >O 50 4, <-- (5,6,7, 44, 45, 46, 47, 84, 85, 86, 87, C4, C5, C6, C7)
// Examine memory:
// >E 8000 will show both lower and upper DRAM banks
//#define use_dramdebug

// define this to have Premium cursor keys on UP, DOWN, LEFT and RIGHT keys.
// if not defined then these are on the function keys.
#define use_cursorkeys

// define the following debug options to report on ports on stdout
#define use_resetinfo
//#define use_pioinfo
//#define use_debug_memmap_mode
//#define use_debug_vdu_colcont_r
//#define use_debug_vdu_colcont_w
//#define use_debug_vdu_lvdat_r
//#define use_debug_vdu_lvdat_w
//#define use_debug_vdu_latchrom

//#define use_debug_disk_read_abort

//#define use_debug_getkeystate_shift
//#define use_debug_getkeystate_lower

// define the following options to be reported to stdout
#define use_info_disk_open
//#define use_info_disk_read

#endif /* HEADER_UBEE512_H */
